% From 2 - Matlab Programming, IO, Strings
% prepared by Gilberto Urroz, August 2004
echo on
%
% MATLAB comparison operators are
%    == equal to
%    < less than
%    > greater than
%    <= less than or equal to
%    >= greater than or equal to
%    ~= not equal to
pause

% MATLAB logical operators are
%    & and
%    | or
%    ~ not
pause

% These are examples of logical statements using comparison 
% and logical operators.  The output is either:
% 1 - true, or 0 - false
pause

3 ~= 2 
pause
3 == 3 
pause
(2>1)&(3>1) 
pause
(2>1)&(3>5) 
pause
(2<1)&(3>1) 
pause
(2<1)&(3>5) 
pause
(2>1) | (3>1) 
pause
(2>1) | (3>5) 
pause
(2<1) | (3>1) 
pause
(2<1) | (3>5) 
pause
~(2<1) 
pause
~(2>1) 
pause
~(2>1) | (3>5) 
pause

% Matlab loops
% The basic construct for the For loop is:
% for index = starting_value : increment : end_value, statements, end
% for index = starting_value : end_value, statements, end
% Examples:
r = 1; for k = 1:0.5:4, r = r+k, end 
pause
xs = -1.0; dx = 0.25; n = 10; for j = 1:n, x = xs + (j-1)*dx; end; x 
pause
for m = 1:10, a(m) = m^2; end; a 
pause

% The basic construct for the While loop is:
% while condition, statements, end
% For example:
s = 100; while s>50, disp(s^2), s = s - 5, end 
pause

% 'For' and 'while' loops can be terminated with the command break
% Example:

for j = 1:10, disp(j), if j>5 break, end, end 
pause

% Conditional constructs in Matlab
%   
%   if condition statement, end
%   if condition statement1, else statement2, end
%   if condition1 statement1, elseif condition2 statement2, else statement3, end
% examples:
x = 10; y = 5; if x> 5 disp(y), end 
pause
x = 3 ; y = 5; if x>5 disp(y), else disp(x), end 
pause
x = 3; y = 5; z = 4; if x>5 disp(x), elseif x>6 disp(y), else disp(z), end 
pause

%The general form of the switch-case construct is:
%  switch variable, case n1, statement, case n2, statement, , end
% Examples:
x = -1; switch x, case 1, y = x+5, case -1, y = sqrt(x), end 
pause
r = 7; switch r, case 1, disp( r), case 2, disp(r^2), case 7, disp(r^3), end 
pause

% M-files in Matlab
% These are files containing executable statements (programs).  They could be:
% 1 - Script files (like the one currently running)
% 2 - Function files (arguments in, results out)
pause

% This Script file has been saved in the 'work' directory and is called from 
% within the present script file for execution 
program1    % -- saved as 'program1.m'
pause

% Functions can be defined inline, e.g.,
Euler = inline('r*exp(i*theta)','r','theta')
pause

% Evaluating the function just defined:
Euler(1.0,-pi/2)
pause

% The following are functions of two variables for converting 
% Cartesian to polar coordinates -- both defined as inline functions
r = inline('sqrt(x^2+y^2)','x','y')
pause
theta = inline('atan(y/x)','x','y')
pause

% evaluations of these functions are shown next:
r(3.,4.), theta(3.,4.) 
pause

%To learn more about the inline command, type: 
help inline 
pause

% Functions in m-files, for example: 'sphecart' (show file)
pause

% M-file functions start with 'function' statement
% Comment lines can be used for information, e.g.,
help sphecart
pause

% Evaluation of the function:
[x1,y1,z1]=sphecart(10.0, pi/3, pi/6) 
pause

% A second example of M-file function: AbsM.m (show file)
pause

% Information on AbsM:
help AbsM
pause

% Evaluation of the function:
R = fix(10*rand(3,4))
pause

AbsM(R)
pause

% Input-Output in Matlab
% ======================
pause

% Saving and loading the workspace
clear    % clear all variables
who      % no variables showns
pause

A = [1. 2. 3.; -3. 4. 5.; 2. 4. 5.; 1. 3. 2.]; b = 1:10; 
who      % variables A and b were created
pause

save 'DataAb.mat'   % save workspace
pause

% Open file 'DataAb.mat' with editor to see it's a binary file

clear    % clear all variables again
who      % no variables showns
pause

load 'DataAB.mat'  % load variables previously saved
A,b                % show variables A and b
pause

% Unformatted output to the screen using function 'disp' - examples:
x = 2; y = 5;r = [x y]; A = [r; 2 3];
disp('x='), disp(x) 
pause

disp('y : '), disp(y) 
pause

disp('vector r is'), disp(r)
pause

disp('matrix A is'), disp(A)
pause

% Reading from the keyboard, using function 'input':
x = input('Enter the value of x:')
pause

x
pause

% To input a string value:
name = input('Enter filename:','s') 
pause

name
pause

% Working with text files - function 'fopen':
help fopen
pause

% Example:
myFile = fopen('c:\results1.txt','w') 
pause

% Number assigned is the file logical number.  
% Logical numbers = 1 or 2 (or none) produce output to the screen
% Examples:
fprintf(1,'hello world! \n') 
pause

x = 3.2; fprintf('The value of x is %f \n',x) 
pause

%Note: function 'fprintf', borrowed from C, C++, C#, prints a string
%For additional information see below 

% Working with files - function 'fclose':
fclose(myFile)
pause

% or fclose(logical number), e.g., fclose(3)
% fclose('all')              closes all open files
% If the result from fclose is 0 means closing was done properly
% If the result is not zero, then a problem will be reported
pause

% Function 'fprintf' produces output
help fprintf
pause

% Examples follow:
% Printing a string
fprintf('\n ---- Output File for Program "Open_Channel" ---- \n\n') 
pause

%NOTES:
% The special formats \n,\r,\t,\b,\f can be used to produce linefeed, carriage
% return, tab, backspace, and form-feed characters respectively.
% Use \\ to produce a backslash character and %% to produce the percent
% character.
pause

% Example of 'fprintf' with special format characters:
fprintf('\nUse \\n to produce a line feed \t\t and these are two tabs.\n\n')
pause

% Example of 'fprintf' using format specifications for integer values (%i)
i2 = 5; jj = -102;
fprintf('\nInteger indices: i2 = %i and jj = %i\n\n',i2,jj)
pause

% If using integer specification (%i) but the values are floating-point
% the results are shown in scientific format:
i2 = 6.23; jj = -102.45;
fprintf('\nInteger indices: i2 = %i and jj = %i\n\n',i2,jj)
pause

% Specifiyng the width of the integer field (e.g., %5i or %10i):
i2 = 5; jj = -102;
fprintf('\nInteger indices: i2 = %5i and jj = %10i\n\n',i2,jj)
pause

% If not space provided in field width, Matlab adjusts the output:
i2 = 5; jj = -102;
fprintf('\nInteger indices: i2 = %2i and jj = %2i\n\n',i2,jj)
pause

% Format specification for floating-point values (%f):
x = 123.45; y = -0.00056;
fprintf('\nReal variables: x = %f and y = %f\n\n',x,y)
pause

% Specifying width (w) and number of decimals (d)
% Format spec: % w.df -- suggested: w >= d + 3
x = 123.45; y = -0.00056;
fprintf('\nReal variables: x = %7.2f and y = %9.5f\n\n',x,y)
pause

% If not enough decimal places allowed, decimals will be truncated:
x = 123.45; y = -0.00056;
fprintf('\nReal variables: x = %7.2f and y = %7.2f\n\n',x,y)
pause

% If width is not long enough, Matlab adjusts the output to fit integer part:
x = 123.45; y = -0.00056;
fprintf('\nReal variables: x = %5.2f and y = %7.5f\n\n',x,y)
pause

% Using d = 0 truncates output to integer part only:
x = 123.45; y = -0.00056;
fprintf('\nReal variables: x = %5.0f and y = %7.0f\n\n',x,y)
pause

% Scientific notation specification for floating-point data (%e):
x = 123.45; y = -0.00056;
fprintf('\nReal variables: x = %e and y = %e\n\n',x,y)
pause

% pecifying width (w) and number of decimals (d)
% Format spec: % w.de -- suggested: w >= d + 8
x = 123.45; y = -0.00056;
fprintf('\nReal variables: x = %e and y = %e\n\n',x,y)
pause

% Using d = 0 truncates the mantissa (i.e., the part that is not the exponent) 
% to an integer, e.g.,
x = 123.45; y = -0.00056;
fprintf('\nReal variables: x = %10.0e and y = %13.0e\n\n',x,y)
pause

% General format for numerical output (%g):
m = 2; r = -12.232123; s = 0.00000000000023;
fprintf('\nSee these values: m = %g, r = %g, and s = %g\n\n',m,r,s)
pause

% When using the format %w.dg, only the width (w) has an effect:
m = 2; r = -12.232123; s = 0.00000000000023;
fprintf('\nSee these values: m = %10.5g, r = %10.5g, and s = %10.5g\n\n',m,r,s)
pause

% The same result is achieved by using %10g rather than %10.5g:
m = 2; r = -12.232123; s = 0.00000000000023;
fprintf('\nSee these values: m = %10g, r = %10g, and s = %10g\n\n',m,r,s)
pause

% Format specification for string variables (%s):
sname = 'Bart Simpson'; prof = 'daredevil';
fprintf('\nHis name is %s and he is a %s.\n\n', sname, prof)
pause

% Combination of format specifications:
jj=23;x=12.4;y=-456.2;title=' North Canal';
fprintf('\nIn iteration no. %2i, x = %g, while y = %f8.2, for case: %s.\n\n', jj, x, y, title)
pause

% A Script to write numerical data to a text file
% See file 'Write1.m'
Write1   %NOTE: run separately, it crashes this script 
% Check file 'c:\Results1.txt' after completing this script
pause

% A fancier output is produced by the following script:
% See file 'Write2.m'
Write2  %NOTE: run separately, it crashes this script
% Check file 'c:\Results2.txt' after completing this script
pause

% Reading data from a file - see script 'Read1.m'
% which uses function 'fscanf'
Read1
pause

% After reading data in we can show the data read as follows:
R           % Original data read
pause

format long % Change format to see more decimals
R
pause

x, y, z      % Show extracted columns
pause

% Manipulating strings in Matlab
% ==============================
% Function 'strcat' is used to concatenate strings:
s1 = 'The result from ';
s2 = 'multiplication ';
s3 = 'is given below.';
sOut = strcat(s1,s2,s3)
pause

% A better result is obtained by using:
s1 = 'The result from ';
s2 = ' multiplication ';
s3 = ' is given below.';
sOut = strcat(s1,s2,s3)
pause

% Another way to do concatenation is shown next:
s1 = 'The result from ';
s2 = 'multiplication ';
s3 = 'is given below.';
sOut = [s1, s2, s3]      % place strings in a row vector
pause

% Other string functions and operations
length(sOut)			    % length of string
pause
findstr(sOut,'mult')     % find occurrence of 'mult' within sOut
pause
sOut(17:24)              % extract sub-string using subindices
pause
sOut = strrep(sOut,'multiplicat','divis')  % substitute strings
pause

% Function 'num2str' converts a number into a string:
s = 5+2; ['The sum is ',num2str(s)]
pause

% Function 'str2num' converts a string into a number:
r = str2num('123.4');
sqrt(r);
pause

% Each character has a numerical value associated with it. The numerical value 
% of a character is given by its ASCII code, which can be obtained by using 
% function 'double'. For example:
[double('0'),double('1'),double('a'),double('b'),double('A')]
pause

% Function 'char' produces the character corresponding to an ASCII code:
char(102)
pause

char(125)
pause

% The variable 'ans'(answer) contains MATLAB's current output. 
% You can refer to the last MATLAB output by using the variable name 'ans'. 
% For example:
3 + 2 
pause

exp(ans)
pause

exp(5)  % verify result
% End of script













